@@ -17,8 +17,8 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef CONTACTGRANTLEEPRINTGEOOBJECT_H
-#define CONTACTGRANTLEEPRINTGEOOBJECT_H
+#ifndef PRINT_CONTACTGRANTLEEGEOOBJECT_H
+#define PRINT_CONTACTGRANTLEEGEOOBJECT_H
 
 #include <QObject>
 #include <kcontacts/geo.h>
@@ -45,4 +45,4 @@ private:
     KContacts::Geo mGeo;
 };
 }
-#endif // CONTACTGRANTLEEPRINTGEOOBJECT_H
+#endif // PRINT_CONTACTGRANTLEEGEOOBJECT_H
