@@ -17,8 +17,8 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef CONTACTGRANTLEEPRINTIMOBJECT_H
-#define CONTACTGRANTLEEPRINTIMOBJECT_H
+#ifndef PRINT_CONTACTGRANTLEEIMOBJECT_H
+#define PRINT_CONTACTGRANTLEEIMOBJECT_H
 #include <QObject>
 namespace KAddressBookGrantlee {
 class ContactGrantleeImObject : public QObject
@@ -31,12 +31,12 @@ public:
     explicit ContactGrantleeImObject(const QString &type, const QString &address, QObject *parent = nullptr);
     ~ContactGrantleeImObject();
 
-    QString type() const;
-    QString address() const;
+    Q_REQUIRED_RESULT QString type() const;
+    Q_REQUIRED_RESULT QString address() const;
 
 private:
     QString mType;
     QString mAddress;
 };
 }
-#endif // CONTACTGRANTLEEPRINTIMOBJECT_H
+#endif // PRINT_CONTACTGRANTLEEIMOBJECT_H
